#  Open Rover

The robot formerly known as "Open Rover" is now "Rover Pro"!

Please update code and documentation to point to the python [`roverpro` package](https://pypi.org/project/roverpro/) instead of `openrover`.
